---
name: r.info
description: Outputs basic information about a raster map.
keywords: [ raster, metadata, extent, history ]
---

# r.info

Outputs basic information about a raster map.

=== "Command line"

    **r.info**
    [**-grseh**]
    **map**=*name*
    **format**=*name*
    [**--verbose**]
    [**--quiet**]
    [**--qq**]
    [**--ui**]

    Example:

    ```sh
    r.info map=name format=plain
    ```

=== "Python (grass.script)"

    *grass.script.parse_command*("***r.info***",
        **map**,
        **format**=*"plain"*,
        **flags**=*None*,
        **verbose**=*False*,
        **quiet**=*False*,
        **superquiet**=*False*)

    Example:

    ```python
    gs.parse_command("r.info", map="name", format="json")
    ```

## Parameters

=== "Command line"

    **map**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of raster map  
    **format**=*name* **[required]**  
    &nbsp;&nbsp;&nbsp;&nbsp;Output format  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *plain, json*  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *plain*  
    &nbsp;&nbsp;&nbsp;&nbsp;**plain**: Plain text output  
    &nbsp;&nbsp;&nbsp;&nbsp;**json**: JSON (JavaScript Object Notation)  
    **-g**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print raster array information in shell script style  
    **-r**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print range in shell script style  
    **-s**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print stats in shell script style  
    **-e**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print extended metadata information in shell script style  
    **-h**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print raster history instead of info  
    **--help**  
    &nbsp;&nbsp;&nbsp;&nbsp;Print usage summary  
    **--verbose**  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    **--quiet**  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    **--qq**  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    **--ui**  
    &nbsp;&nbsp;&nbsp;&nbsp;Force launching GUI dialog

=== "Python (grass.script)"

    **map** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Name of raster map  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: input, raster, *name*  
    **format** : str, *required*  
    &nbsp;&nbsp;&nbsp;&nbsp;Output format  
    &nbsp;&nbsp;&nbsp;&nbsp;Used as: *name*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *plain, json*  
    &nbsp;&nbsp;&nbsp;&nbsp;**plain**: Plain text output  
    &nbsp;&nbsp;&nbsp;&nbsp;**json**: JSON (JavaScript Object Notation)  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *plain*  
    **flags** : str, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Allowed values: *g*, *r*, *s*, *e*, *h*  
    &nbsp;&nbsp;&nbsp;&nbsp;**g**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print raster array information in shell script style  
    &nbsp;&nbsp;&nbsp;&nbsp;**r**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print range in shell script style  
    &nbsp;&nbsp;&nbsp;&nbsp;**s**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print stats in shell script style  
    &nbsp;&nbsp;&nbsp;&nbsp;**e**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print extended metadata information in shell script style  
    &nbsp;&nbsp;&nbsp;&nbsp;**h**  
    &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Print raster history instead of info  
    **verbose**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Verbose module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **quiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*  
    **superquiet**: bool, *optional*  
    &nbsp;&nbsp;&nbsp;&nbsp;Very quiet module output  
    &nbsp;&nbsp;&nbsp;&nbsp;Default: *False*

## DESCRIPTION

*r.info* reports some basic information about a user-specified raster
map layer. This map layer must exist in the user's current mapset search
path. Information about the map's boundaries, resolution, projection,
data type, category number, project, mapset, project parent directory
(database directory), the timestamp and history are put into a table and
written to standard output. The types of information listed can also be
found in the *cats*, *cellhd*, and *hist* directories under the mapset
in which the named map is stored.

The user can save the tabular output to a file by using the UNIX
redirection mechanism (\>); for example, the user might save a report on
the *soils* map layer in a file called *soil.txt* by typing:

```sh
r.info map=soils > soil.txt
```

## NOTES

On large maps, the total number of cells in the map may not be displayed
with an accurate number. This is only cosmetic.

Some standards (ISO-C90) and compilers do not support the 'long long'
type as a 64-bit type. In the case that GRASS was built with such a
compiler, an accuracy message may be displayed in the output of *r.info*
after Total Cells.

## EXAMPLES

Below is a full report produced by *r.info* for the raster map *slope*
in the North Carolina sample data base:

```sh
r.info slope
 +----------------------------------------------------------------------------+
 | Map:      slope                          Date: Tue Nov  7 01:11:23 2006    |
 | Mapset:   PERMANENT                      Login of Creator: helena          |
 | Project:  nc_spm_08_grass7                                                 |
 | DataBase: /grassdata                                                       |
 | Title:    South-West Wake county: slope in degrees ( slope_ned10m )        |
 | Timestamp: none                                                            |
 |----------------------------------------------------------------------------|
 |                                                                            |
 |   Type of Map:  raster               Number of Categories: 255             |
 |   Data Type:    FCELL                                                      |
 |   Rows:         1350                                                       |
 |   Columns:      1500                                                       |
 |   Total Cells:  2025000                                                    |
 |        Projection: Lambert Conformal Conic                                 |
 |            N:     228500    S:     215000   Res:    10                     |
 |            E:     645000    W:     630000   Res:    10                     |
 |   Range of data:    min = 0  max = 38.68939                                |
 |                                                                            |
 |   Data Source:                                                             |
 |    raster elevation file elev_ned10m                                       |
 |                                                                            |
 |                                                                            |
 |   Data Description:                                                        |
 |    generated by r.slope.aspect                                             |
 |                                                                            |
 |   Comments:                                                                |
 |    slope map elev = elev_ned10m                                            |
 |    zfactor = 1.00 format = degrees                                         |
 |    min_slope = 0.000000                                                    |
 |                                                                            |
 +----------------------------------------------------------------------------+
```

Alternatively, the output from *r.info* may be confined to a more terse
subset of the available information by passing various flags to the
module:

Output in shell script style, useful for eval
(`` eval `r.info -g slope` ``):

```sh
r.info -g slope
north=228500
south=215000
east=645000
west=630000
nsres=10
ewres=10
rows=1350
cols=1500
cells=2025000
datatype=FCELL
ncats=255
```

Output the map data range:

```sh
r.info -r slope
min=0
max=38.68939
```

Output the extended map data metadata in shell style:

```sh
r.info -e slope
map=slope
mapset=PERMANENT
project=nc_spm_08_grass7
database=/grassdata
date="Tue Nov  7 01:11:23 2006"
creator="helena"
title="South-West Wake county: slope in degrees (slope_ned10m)"
timestamp="none"
units="none"
vdatum="none"
semantic_label="none"
source1="raster elevation file elev_ned10m"
source2=""
description="generated by r.slope.aspect"
comments="slope map elev = elev_ned10mzfactor = 1.00 format = degreesmin_slp_allowed = 0.000000"
```

Finally, the output from *r.info* can be output in JSON by passing the
**format=json** option.

```sh
r.info slope format=json
```

```json
{
    "north": 228500,
    "south": 215000,
    "nsres": 10,
    "east": 645000,
    "west": 630000,
    "ewres": 10,
    "rows": 1350,
    "cols": 1500,
    "cells": 2025000,
    "datatype": "FCELL",
    "ncats": 255,
    "min": 0,
    "max": 38.68939208984375,
    "map": "slope",
    "maptype": "raster",
    "mapset": "PERMANENT",
    "location": "nc_spm_08_grass7",
    "project": "nc_spm_08_grass7",
    "database": "/grassdata",
    "date": "Tue Nov  7 01:11:23 2006",
    "creator": "helena",
    "title": "South-West Wake county: slope in degrees",
    "timestamp": null,
    "units": null,
    "vdatum": null,
    "semantic_label": null,
    "source1": "raster elevation file elev_ned10m",
    "source2": "",
    "description": "generated by r.slope.aspect",
    "comments": [
        "slope map elev = elev_ned10m",
        "zfactor = 1.00 format = degrees",
        "min_slp_allowed = 0.000000"
    ]
}
```

## SEE ALSO

*[g.mapsets](g.mapsets.md), [r.coin](r.coin.md),
[r.describe](r.describe.md), [r.report](r.report.md),
[r.stats](r.stats.md), [r.support](r.support.md),
[r.univar](r.univar.md), [r.what](r.what.md)*

## AUTHOR

Michael O'Shea, [U.S. Army Construction Engineering Research
Laboratory](http://www.cecer.army.mil/)

## SOURCE CODE

Available at: [r.info source code](https://github.com/OSGeo/grass/tree/main/raster/r.info)
([history](https://github.com/OSGeo/grass/commits/main/raster/r.info))  
Latest change: Wednesday May 21 09:11:03 2025 in commit [4510205](https://github.com/OSGeo/grass/commit/45102055f4f205276ad5f85b5775b70c6583a26f)
